#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghcide
version:              2.3.0.0
visibility:           public
id:                   ghcide-2.3.0.0-9PCyYEJ8DdPDmbAzFk7XSu
key:                  ghcide-2.3.0.0-9PCyYEJ8DdPDmbAzFk7XSu
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2020
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             The core of an IDE
description:          A library for building Haskell IDE'\''s on top of the GHC API.
category:             Development
abi:                  019a8d5f5d653a15255c2947ef7c0769
exposed:              True
exposed-modules:
    Control.Concurrent.Strict Development.IDE
    Development.IDE.Core.Actions Development.IDE.Core.Compile
    Development.IDE.Core.Debouncer Development.IDE.Core.FileStore
    Development.IDE.Core.FileUtils
    Development.IDE.Core.IdeConfiguration
    Development.IDE.Core.OfInterest Development.IDE.Core.PluginUtils
    Development.IDE.Core.PositionMapping
    Development.IDE.Core.Preprocessor
    Development.IDE.Core.ProgressReporting
    Development.IDE.Core.RuleTypes Development.IDE.Core.Rules
    Development.IDE.Core.Service Development.IDE.Core.Shake
    Development.IDE.Core.Tracing Development.IDE.Core.UseStale
    Development.IDE.GHC.Compat Development.IDE.GHC.Compat.Core
    Development.IDE.GHC.Compat.Env Development.IDE.GHC.Compat.Iface
    Development.IDE.GHC.Compat.Logger
    Development.IDE.GHC.Compat.Outputable
    Development.IDE.GHC.Compat.Parser
    Development.IDE.GHC.Compat.Plugins Development.IDE.GHC.Compat.Units
    Development.IDE.GHC.Compat.Util Development.IDE.GHC.CoreFile
    Development.IDE.GHC.Error Development.IDE.GHC.Orphans
    Development.IDE.GHC.Util
    Development.IDE.Import.DependencyInformation
    Development.IDE.Import.FindImports
    Development.IDE.LSP.HoverDefinition
    Development.IDE.LSP.LanguageServer
    Development.IDE.LSP.Notifications Development.IDE.LSP.Outline
    Development.IDE.LSP.Server Development.IDE.Main
    Development.IDE.Main.HeapStats Development.IDE.Monitoring.EKG
    Development.IDE.Monitoring.OpenTelemetry Development.IDE.Plugin
    Development.IDE.Plugin.Completions
    Development.IDE.Plugin.Completions.Types Development.IDE.Plugin.HLS
    Development.IDE.Plugin.HLS.GhcIde Development.IDE.Plugin.Test
    Development.IDE.Plugin.TypeLenses Development.IDE.Session
    Development.IDE.Session.Diagnostics Development.IDE.Spans.AtPoint
    Development.IDE.Spans.Common Development.IDE.Spans.Documentation
    Development.IDE.Spans.LocalBindings Development.IDE.Spans.Pragmas
    Development.IDE.Types.Diagnostics Development.IDE.Types.Exports
    Development.IDE.Types.HscEnvEq Development.IDE.Types.KnownTargets
    Development.IDE.Types.Location Development.IDE.Types.Monitoring
    Development.IDE.Types.Options Development.IDE.Types.Shake
    Generics.SYB.GHC Text.Fuzzy.Parallel

hidden-modules:
    Development.IDE.Core.FileExists Development.IDE.GHC.CPP
    Development.IDE.GHC.Warnings
    Development.IDE.Plugin.Completions.Logic
    Development.IDE.Session.VersionCheck Development.IDE.Types.Action

import-dirs:          /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide
hs-libraries:         HSghcide-2.3.0.0-9PCyYEJ8DdPDmbAzFk7XSu
depends:
    Diff-1.0-Lm5Fw8fjuFK17wB6yKmBme Glob-0.10.2-85huPVQ78toBRD8Sm7F5mN
    aeson-2.2.2.0-D5UyU4s17IF6uKIJTSur7o array-0.5.6.0
    async-2.2.6-5xQ7XDEe3v3DeLHeJRStgT base-4.18.2.1
    base16-bytestring-1.0.2.0-K0QjIJ8Wcv0Kwq3shHOJke binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-3KPQ2ag2hyl5eroFFm5hRO
    co-log-core-0.3.2.6-C02N1u6eHmY62M8olacMZA containers-0.6.7
    cryptohash-sha1-0.11.101.0-8m6dGgvWIl487ZX14guT6L
    data-default-0.7.1.3-CRQVneoi5B7He0Tx6HSYSU deepseq-1.4.8.1
    dependent-map-0.4.0.1-GhErIv4Kp4a5mRF2CHI1P8
    dependent-sum-0.7.2.0-80IaefhetAUFbXfIph83O4 directory-1.3.8.5
    dlist-1.0-Eygr3YxXU3I4OAzq8xpe04
    enummapset-0.7.3.0-GTrCMZkhGZx30bCzvngb4j exceptions-0.10.7
    extra-1.7.16-92gEBqN3yIpF5We3DBC4D filepath-1.4.300.1
    fingertree-0.1.6.3-3uJCxguOv6s1OIdHehYFEb
    focus-1.0.3.2-Dt5AaUp5CLoKbE5xpAwcHl ghc-9.6.6 ghc-boot-9.6.6
    ghc-boot-th-9.6.6 ghc-check-0.5.0.8-CQdHcwjfQ4WFpwUGDoRPkr
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    ghc-trace-events-0.1.2.10-H26I0MYftT2GE85bySiIsN
    haddock-library-1.11.0-GlLo4ykwH3BCpERZb05wOS
    hashable-1.4.7.0-4qZi9v5WFMZ3p1WVFpevAr
    hie-bios-0.12.0-KmmHC0wYatlEG4eaojg8Dz
    hie-compat-0.3.1.2-37lTPgU0jdr1Ufn5QvEKoZ
    hiedb-0.4.3.0-27bJatdPLn98DjsOqTKP1s
    hls-graph-2.3.0.0-Illm4SFcQuX6uLsIon2QHH
    hls-plugin-api-2.3.0.0-JVLUQ4iVhTnBYOG8szZCVe
    implicit-hie-0.1.4.0-8DukwtTcbHlE3wafWyXWIK
    implicit-hie-cradle-0.5.0.1-JSeoyuA9HZGjRbA4JvHCK
    lens-5.3.5-Hxc0anWDJEt7cb0Yel4vbI
    list-t-1.0.5.7-AmWGljUb4dk8MqD0Qqqlfj
    lsp-2.2.0.0-E2aHCV3sthyE2PT79gGCKX
    lsp-types-2.0.2.0-6ZTe68cmYvYAUNdF7MbJk2 mtl-2.3.1
    opentelemetry-0.8.0-KZmZeFSKp17AoqQfLeXtdB
    optparse-applicative-0.18.1.0-6cREMRvcEOW6x5IeiCw6lt
    parallel-3.2.2.0-4GFGhbl8Ae06nPoqdIyBUD
    prettyprinter-1.7.1-4EZkWc5tq0yFCEPbAPD9Qw
    prettyprinter-ansi-terminal-1.1.4-Hjmzev0gSkeIf1zTaF3b5Y
    random-1.2.1.3-1S1SEs3xtKIgpnjewCuMr
    regex-tdfa-1.3.2.5-GDcLEW3RNnhJam1iRhMaaH
    row-types-1.0.1.2-DHoemNvC0O2DsPFIRhbMaC
    safe-exceptions-0.1.7.4-J6rtfAXDyMB77zQjT5hSt
    sorted-list-0.2.3.1-H1i6tXWYLq0GXIgbbM5KLo
    sqlite-simple-0.4.19.0-JpJKljS6mH5IjQsH4x3dy9 stm-2.5.1.0
    stm-containers-1.2.1.1-7SDaDbjVOyRAjaAwl5lmET
    syb-0.7.3-IWvKvWWONKwAx7053zcTAl text-2.0.2
    text-rope-0.3-FEQxRWPNIur5YmGMM3Ex2E time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unliftio-0.2.25.1-8EuOvwMQbnH3C5Rgo2gyOI
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-4LGdNZVNGNC9SVCFAuU8Mp
    vector-0.13.2.0-EFjd2WQg5nEG5BmM55CoiV

haddock-interfaces:   /usr/share/doc/haskell-ghcide/html/ghcide.haddock
haddock-html:         /usr/share/doc/haskell-ghcide/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

